Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(519)

Unified Diff: runtime/bin/vmservice/server.dart

Issue 1411853003: Service isolate requests Observatory assets from embedder (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/bin/vmservice/resources.dart ('k') | runtime/bin/vmservice/vmservice_io.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/bin/vmservice/server.dart
diff --git a/runtime/bin/vmservice/server.dart b/runtime/bin/vmservice/server.dart
index 8697e659259c0b7ddb3662e2aa17733c492fabb5..394315f4527c3e6f9bc4b735ba70757f09371bf0 100644
--- a/runtime/bin/vmservice/server.dart
+++ b/runtime/bin/vmservice/server.dart
@@ -136,12 +136,12 @@ class Server {
return;
}
- var resource = Resource.resources[path];
- if (resource != null) {
- // Serving up a static resource (e.g. .css, .html, .png).
+ Asset asset = assets[path];
+ if (asset != null) {
+ // Serving up a static asset (e.g. .css, .html, .png).
request.response.headers.contentType =
- ContentType.parse(resource.mimeType);
- request.response.add(resource.data);
+ ContentType.parse(asset.mimeType);
+ request.response.add(asset.data);
request.response.close();
return;
}
« no previous file with comments | « runtime/bin/vmservice/resources.dart ('k') | runtime/bin/vmservice/vmservice_io.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698